#ifndef NT2_INCLUDE_CONSTANTS_TWENTY_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWENTY_HPP_INCLUDED

#include <nt2/constant/include/constants/twenty.hpp>

#endif
